@@ -16,7 +16,7 @@ try:
 except ImportError:
     from urllib import unquote
 
-__version__ = "0.7.1"
+__version__ = "1.0.0"
 
 
 def listdir(directory):
@@ -122,11 +122,10 @@ class Client(object):
         server_token = '{login}:{password}'.format(login=self.webdav.login, password=self.webdav.password)
         self.default_options.update({
             'URL': self.webdav.hostname,
-            'SSL_VERIFYPEER': 0,
-            'SSL_VERIFYHOST': 0,
             'USERPWD': server_token,
-            'NOBODY': 1
-            #'SSLVERSION': pycurl.SSLVERSION_TLSv1,
+            'NOBODY': 1,
+            'SSL_VERIFYPEER': 0,
+ 			'SSL_VERIFYHOST': 0
         })
 
         if self.proxy.valid():
